@@ -324,21 +324,27 @@ class StaxPipeline:
                                     "Action": [
                                         "cloudformation:CreateStackInstances",
                                         "cloudformation:DeleteStackInstances",
+                                        "cloudformation:DeleteStack",
                                         "cloudformation:ListStackInstances",
                                         "cloudformation:DescribeStackSet",
+                                        "cloudformation:DescribeStacks",
                                         "cloudformation:UpdateStackSet",
+                                        "cloudformation:UpdateStack",
                                         "cloudformation:GetTemplateSummary",
                                         "cloudformation:TagResource",
                                     ],
                                     "Resource": [
                                         Sub(
-                                            "arn:${AWS::Partition}:cloudformation:${AWS::Region}:${AWS::AccountId}:stackset/${Namespace}-*",
+                                            "arn:${AWS::Partition}:cloudformation:*:${AWS::AccountId}:stackset/${Namespace}-*",
+                                        ),
+                                        Sub(
+                                            "arn:${AWS::Partition}:cloudformation:*:${AWS::AccountId}:stack/${Namespace}-*",
                                         ),
                                         Sub(
                                             "arn:${AWS::Partition}:cloudformation:*:${AWS::AccountId}:stackset-target/${Namespace}-*",
                                         ),
                                         Sub(
-                                            "arn:${AWS::Partition}:cloudformation:${AWS::Region}::type/resource/*",
+                                            "arn:${AWS::Partition}:cloudformation:*::type/resource/*",
                                         ),
                                     ],
                                 },
@@ -347,8 +353,10 @@ class StaxPipeline:
                                     "Effect": "Allow",
                                     "Action": [
                                         "cloudformation:CreateStackSet",
+                                        "cloudformation:CreateStack",
                                         "cloudformation:DescribeStackSet",
                                         "cloudformation:ListStackSets",
+                                        "cloudformation:ListStacks",
                                     ],
                                     "Resource": "*",
                                 },
@@ -398,7 +406,7 @@ class StaxPipeline:
                 ),
                 Environment=codebuild.Environment(
                     ComputeType="BUILD_GENERAL1_SMALL",
-                    Image="ghcr.io/hyperscale-consulting/stax@sha256:2cea6c590191f6a4f339a5dfb0dd9dd0cf9801d423c95aa92c39e64fdafba7f8",
+                    Image="ghcr.io/hyperscale-consulting/stax@sha256:cb58976dc7479dced3afc4c803f56faa6035338dfc9720354794d29b490cc401",
                     Type="LINUX_CONTAINER",
                 ),
                 Source=codebuild.Source(
